@@ -27,5 +27,12 @@ int demo(char *a, char *b) {
  /* Flawfinder: ignore */
  gets(f);
  gets(f);
+ /* These are okay, but flawfinder version < 0.20 incorrectly used
+    the first parameter as the parameter for the format string */
+ syslog(LOG_ERR,"cannot open config file (%s): %s",filename,strerror(errno))
+ syslog(LOG_CRIT,"malloc() failed");
+ /* But this one SHOULD trigger a warning. */
+ syslog(LOG_ERR, attacker_string);
+
 }
 
